pub struct VectorIndexStatus {
pub revision: VectorRevision,
pub partition_count: usize,
pub record_count: usize,
pub byte_count: usize,
}Expand description
Current logical size and published revision of an index.
Fields
revision: VectorRevisionpartition_count: usizerecord_count: usizebyte_count: usizeAccounted vector and caller metadata bytes in the current snapshot.